"""This is part of the MSS Python's module.
Source: https://github.com/BoboTiG/python-mss.
"""

import itertools
import os
import os.path
from pathlib import Path

import pytest

from mss import mss

Image = pytest.importorskip("PIL.Image", reason="PIL module not available.")


def test_pil() -> None:
    width, height = 16, 16
    box = {"top": 0, "left": 0, "width": width, "height": height}
    with mss(display=os.getenv("DISPLAY")) as sct:
        sct_img = sct.grab(box)

    img = Image.frombytes("RGB", sct_img.size, sct_img.rgb)
    assert img.mode == "RGB"
    assert img.size == sct_img.size

    for x, y in itertools.product(range(width), range(height)):
        assert img.getpixel((x, y)) == sct_img.pixel(x, y)

    output = Path("box.png")
    img.save(output)
    assert output.is_file()


def test_pil_bgra() -> None:
    width, height = 16, 16
    box = {"top": 0, "left": 0, "width": width, "height": height}
    with mss(display=os.getenv("DISPLAY")) as sct:
        sct_img = sct.grab(box)

    img = Image.frombytes("RGB", sct_img.size, sct_img.bgra, "raw", "BGRX")
    assert img.mode == "RGB"
    assert img.size == sct_img.size

    for x, y in itertools.product(range(width), range(height)):
        assert img.getpixel((x, y)) == sct_img.pixel(x, y)

    output = Path("box-bgra.png")
    img.save(output)
    assert output.is_file()


def test_pil_not_16_rounded() -> None:
    width, height = 10, 10
    box = {"top": 0, "left": 0, "width": width, "height": height}
    with mss(display=os.getenv("DISPLAY")) as sct:
        sct_img = sct.grab(box)

    img = Image.frombytes("RGB", sct_img.size, sct_img.rgb)
    assert img.mode == "RGB"
    assert img.size == sct_img.size

    for x, y in itertools.product(range(width), range(height)):
        assert img.getpixel((x, y)) == sct_img.pixel(x, y)

    output = Path("box.png")
    img.save(output)
    assert output.is_file()



# Lets prevent misses, and import the module to get the proper version.
# So that the version in only defined once across the whole code base:
#   src/mss/__init__.py
import sys
from pathlib import Path

sys.path.insert(0, str(Path(__file__).parent.parent.parent / "src"))

import mss

# -- General configuration ------------------------------------------------

extensions = ["sphinx.ext.intersphinx"]
templates_path = ["_templates"]
source_suffix = {".rst": "restructuredtext"}
master_doc = "index"

# General information about the project.
project = "Python MSS"
copyright = f"{mss.__date__}, {mss.__author__} & contributors"  # noqa:A001
author = mss.__author__
version = mss.__version__

release = "latest"
language = "en"
todo_include_todos = True


# -- Options for HTML output ----------------------------------------------

html_theme = "default"
htmlhelp_basename = "PythonMSSdoc"


# -- Options for Epub output ----------------------------------------------

# Bibliographic Dublin Core info.
epub_title = project
epub_author = author
epub_publisher = author
epub_copyright = copyright

# A list of files that should not be packed into the epub file.
epub_exclude_files = ["search.html"]


# ----------------------------------------------

# Example configuration for intersphinx: refer to the Python standard library.
intersphinx_mapping = {"python": ("https://docs.python.org/3", None)}



"""This is part of the MSS Python's module.
Source: https://github.com/BoboTiG/python-mss.
"""

import os
import os.path

import pytest

from mss import mss

np = pytest.importorskip("numpy", reason="Numpy module not available.")


def test_numpy(pixel_ratio: int) -> None:
    box = {"top": 0, "left": 0, "width": 10, "height": 10}
    with mss(display=os.getenv("DISPLAY")) as sct:
        img = np.array(sct.grab(box))
    assert len(img) == 10 * pixel_ratio
